@@ -6,7 +6,7 @@
 # ******************************************
 # If it does not work, try with baud = 9600
 #
-# $Id: shell.pl,v 1.6 2005/04/30 21:45:47 cosimo Exp $
+# $Id: shell.pl,v 1.6 2005-04-30 21:45:47 cosimo Exp $
 
 use strict;
 use Device::Modem;
@@ -28,7 +28,7 @@ chomp $baud;
 
 $baud ||= 19200;
 
-my $modem = new Device::Modem ( port => $port );
+my $modem = Device::Modem->new( port => $port );
 my $stop;
 
 die "Could not connect to $port!\n" unless $modem->connect( baudrate => $baud );
@@ -55,4 +55,3 @@ while( not $stop ) {
 }
 
 print "Done.\n";
-
